package com.ruoyi.cs.service;

import java.util.Date;
import java.util.List;
import com.ruoyi.cs.domain.CsUserNetworkInfo;
import com.ruoyi.cs.domain.dto.CsUserNetworkInfoAddDTO;
import com.ruoyi.cs.domain.vo.CsUserNetworkInfoVO;

/**
 * 用户端网络信息Service接口
 * 
 * @author ruoyi
 * @date 2024-04-27
 */
public interface ICsUserNetworkInfoService 
{
    /**
     * 查询用户端网络信息
     * 
     * @param networkInfoId 用户端网络信息主键
     * @return 用户端网络信息
     */
    public CsUserNetworkInfo selectCsUserNetworkInfoByNetworkInfoId(String networkInfoId);

    /**
     * 查询用户端网络信息列表
     * 
     * @param csUserNetworkInfo 用户端网络信息
     * @return 用户端网络信息集合
     */
    public List<CsUserNetworkInfo> selectCsUserNetworkInfoList(CsUserNetworkInfo csUserNetworkInfo);

    /**
     * 新增用户端网络信息
     * 
     * @param csUserNetworkInfo 用户端网络信息
     * @return 结果
     */
    public int insertCsUserNetworkInfo(CsUserNetworkInfo csUserNetworkInfo);

    /**
     * 修改用户端网络信息
     * 
     * @param csUserNetworkInfo 用户端网络信息
     * @return 结果
     */
    public int updateCsUserNetworkInfo(CsUserNetworkInfo csUserNetworkInfo);

    /**
     * 批量删除用户端网络信息
     * 
     * @param networkInfoIds 需要删除的用户端网络信息主键集合
     * @return 结果
     */
    public int deleteCsUserNetworkInfoByNetworkInfoIds(String[] networkInfoIds);

    /**
     * 删除用户端网络信息信息
     * 
     * @param networkInfoId 用户端网络信息主键
     * @return 结果
     */
    public int deleteCsUserNetworkInfoByNetworkInfoId(String networkInfoId);

    /**
     * 批量新增(覆盖)用户端网络信息
     * @param list 映射信息列表
     * @param applyId 申请资源id
     * @param createAt 创建时间
     * @param resType 资源类型：0-资源，1-工单
     * @return
     */
    public int batchCoverUserNetwork(List<CsUserNetworkInfoAddDTO> list, String applyId, Date createAt, String resType);


    /**
     * 获取工单相关的用户网络信息列表
     * @param resId 申请id
     * @param resType 申请类型（0-资源，1-工单)
     * @return
     */
    public List<CsUserNetworkInfoVO> selectUserNetworkInfoVOList(String resId, String resType);
}
